@@ -1,6 +1,6 @@
 package Tapper::Schema::TestrunDB::Result::BenchAdditionalTypeRelations;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Schema::TestrunDB::Result::BenchAdditionalTypeRelations::VERSION = '5.0.3';
+$Tapper::Schema::TestrunDB::Result::BenchAdditionalTypeRelations::VERSION = '5.0.4';
 # ABSTRACT: Tapper - additional values for benchmark data point
 
 use strict;
@@ -22,10 +22,10 @@ __PACKAGE__->add_columns(
         },
     },
     'bench_additional_type_id', {
-        data_type           => 'TINYINT',
+        data_type           => 'SMALLINT',
         default_value       => undef,
         is_nullable         => 0,
-        size                => 4,
+        size                => 6,
         is_foreign_key      => 1,
         extra               => {
             unsigned => 1,
