@@ -1,6 +1,6 @@
 package Tapper::Schema::TestrunDB::Result::BenchAdditionalTypes;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Schema::TestrunDB::Result::BenchAdditionalTypes::VERSION = '5.0.3';
+$Tapper::Schema::TestrunDB::Result::BenchAdditionalTypes::VERSION = '5.0.4';
 # ABSTRACT: Tapper - types of additional values for benchmark data points
 
 use strict;
@@ -12,10 +12,10 @@ __PACKAGE__->load_components(qw/InflateColumn::DateTime Core/);
 __PACKAGE__->table('bench_additional_types');
 __PACKAGE__->add_columns(
     'bench_additional_type_id', {
-        data_type           => 'TINYINT',
+        data_type           => 'SMALLINT',
         default_value       => undef,
         is_nullable         => 0,
-        size                => 4,
+        size                => 6,
         is_auto_increment   => 1,
         extra               => {
             unsigned => 1,
@@ -25,7 +25,7 @@ __PACKAGE__->add_columns(
         data_type           => 'VARCHAR',
         default_value       => undef,
         is_nullable         => 0,
-        size                => 512,
+        size                => 767,
     },
     'created_at', {
         data_type           => 'TIMESTAMP',
