@@ -1,6 +1,6 @@
 package Tapper::Schema::TestrunDB::Result::BenchBackupValues;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Schema::TestrunDB::Result::BenchBackupValues::VERSION = '5.0.3';
+$Tapper::Schema::TestrunDB::Result::BenchBackupValues::VERSION = '5.0.4';
 # ABSTRACT: Tapper - backup table for data points for benchmark
 
 use strict;
@@ -42,10 +42,10 @@ __PACKAGE__->add_columns(
         },
     },
     'bench_subsume_type_id', {
-        data_type           => 'TINYINT',
+        data_type           => 'SMALLINT',
         default_value       => undef,
         is_nullable         => 0,
-        size                => 4,
+        size                => 6,
         is_foreign_key      => 1,
         extra               => {
             unsigned => 1,
@@ -54,7 +54,8 @@ __PACKAGE__->add_columns(
     'bench_value', {
         data_type           => 'VARCHAR',
         default_value       => undef,
-        is_nullable         => 512,
+        is_nullable         => 0,
+        size                => 767,
     },
     'active', {
         data_type           => 'TINYINT',
