@@ -1,6 +1,6 @@
 package Tapper::Schema::TestrunDB::Result::BenchValues;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Schema::TestrunDB::Result::BenchValues::VERSION = '5.0.3';
+$Tapper::Schema::TestrunDB::Result::BenchValues::VERSION = '5.0.4';
 # ABSTRACT: Tapper - containing data points for benchmark
 
 use strict;
@@ -32,10 +32,10 @@ __PACKAGE__->add_columns(
         },
     },
     'bench_subsume_type_id', {
-        data_type           => 'TINYINT',
+        data_type           => 'SMALLINT',
         default_value       => undef,
         is_nullable         => 0,
-        size                => 4,
+        size                => 6,
         is_foreign_key      => 1,
         extra               => {
             unsigned => 1,
@@ -44,7 +44,8 @@ __PACKAGE__->add_columns(
     'bench_value', {
         data_type           => 'VARCHAR',
         default_value       => undef,
-        is_nullable         => 512,
+        is_nullable         => 0,
+        size                => 767,
     },
     'active', {
         data_type           => 'TINYINT',
