@@ -1,7 +1,7 @@
 package Tapper::Schema::TestrunDB::Result::View020TestrunOverview;
 our $AUTHORITY = 'cpan:TAPPER';
 # the number is to sort classes on deploy
-$Tapper::Schema::TestrunDB::Result::View020TestrunOverview::VERSION = '5.0.3';
+$Tapper::Schema::TestrunDB::Result::View020TestrunOverview::VERSION = '5.0.4';
 use 5.010;
 use strict;
 use warnings;
@@ -31,7 +31,7 @@ __PACKAGE__->result_source_instance->view_definition
      "from view_testrun_overview_reports vtor, ".
      "     report report, ".
      "     suite suite ".
-     "where CAST(vtor.primary_report_id as INTEGER)=report.id and ".
+     "where CAST(vtor.primary_report_id as UNSIGNED INTEGER)=report.id and ".
      "      report.suite_id=suite.id"
     );
 
